ayttm-commits
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Ayttm-commits] CVS: ayttm/src account.h,1.9,1.10 chat_window.c,1.35,1.3


From: Philip S Tellis <address@hidden>
Subject: [Ayttm-commits] CVS: ayttm/src account.h,1.9,1.10 chat_window.c,1.35,1.36 contact.h,1.5,1.6 llist.c,1.6,1.7 llist.h,1.3,1.4 message_parse.h,1.4,1.5 plugin.h,1.4,1.5 plugin_api.c,1.8,1.9 plugin_api.h,1.3,1.4 prefs.c,1.26,1.27 sound.c,1.12,1.13 status.c,1.36,1.37 util.c,1.27,1.28 util.h,1.15,1.16
Date: Mon, 27 Jan 2003 08:48:42 -0500

Update of /cvsroot/ayttm/ayttm/src
In directory subversions:/tmp/cvs-serv29685/src

Modified Files:
        account.h chat_window.c contact.h llist.c llist.h 
        message_parse.h plugin.h plugin_api.c plugin_api.h prefs.c 
        sound.c status.c util.c util.h 
Log Message:
glib stuff

Index: account.h
===================================================================
RCS file: /cvsroot/ayttm/ayttm/src/account.h,v
retrieving revision 1.9
retrieving revision 1.10
diff -u -r1.9 -r1.10
--- account.h   24 Jan 2003 13:34:41 -0000      1.9
+++ account.h   27 Jan 2003 13:48:19 -0000      1.10
@@ -27,7 +27,6 @@
 #ifndef __ACCOUNT_H__
 #define __ACCOUNT_H__
 
-#include <glib.h>      /* Remove this eventually */
 #include "llist.h"
 
 struct contact;
@@ -47,8 +46,20 @@
        int contacts_shown;
 } grouplist;
 
+typedef struct local_account {
+        int service_id;
+        char *handle;
+       char alias[255];
+        int connected;
+        int connecting;
+       void * status_button; /* GtkWidget */
+       LList * status_menu;
+        void *protocol_local_account_data;
+} eb_local_account;
+
 typedef struct account {
         int service_id;
+       eb_local_account * ela;
         char handle[255];
        struct contact * account_contact;
         void * protocol_account_data;
@@ -60,18 +71,6 @@
        int status_handler;
        struct _info_window * infowindow;
 } eb_account;
-
-
-typedef struct local_account {
-        int service_id;
-        char *handle;
-       char alias[255];
-        int connected;
-        int connecting;
-       void * status_button; /* GtkWidget */
-       GSList * status_menu;
-        void *protocol_local_account_data;
-} eb_local_account;
 
 int load_accounts();
 int load_contacts();

Index: chat_window.c
===================================================================
RCS file: /cvsroot/ayttm/ayttm/src/chat_window.c,v
retrieving revision 1.35
retrieving revision 1.36
diff -u -r1.35 -r1.36
--- chat_window.c       25 Jan 2003 00:10:33 -0000      1.35
+++ chat_window.c       27 Jan 2003 13:48:19 -0000      1.36
@@ -729,7 +729,7 @@
                menu_data *md=NULL;
                menu_item_data *mid=NULL;
                ebmContactData *ecd=NULL;
-               GList *list=NULL;
+               LList *list=NULL;
 
                gtk_signal_emit_stop_by_name(GTK_OBJECT(widget),
                                               "button_press_event");
@@ -810,7 +810,7 @@
                        for(list = md->menu_items; list; list  = list->next ) {
                                ecd=ebmContactData_new();
                                ecd->contact=cw->contact->nick;
-                               mid=(menu_item_data *)list->data;
+                               mid=list->data;
                                mid->data=(ebmCallbackData *)ecd;
                                eb_debug(DBG_CORE, "adding chat window item: 
%s\n", mid->label);
                                button = 
gtk_menu_item_new_with_label(mid->label);

Index: contact.h
===================================================================
RCS file: /cvsroot/ayttm/ayttm/src/contact.h,v
retrieving revision 1.5
retrieving revision 1.6
diff -u -r1.5 -r1.6
--- contact.h   24 Jan 2003 13:34:41 -0000      1.5
+++ contact.h   27 Jan 2003 13:48:19 -0000      1.6
@@ -32,15 +32,15 @@
 
 
 struct contact {
-       gchar nick[255];
-       gchar language[3];
+       char nick[255];
+       char language[3];
        trigger_struct trigger;
        LList *accounts;
-       gboolean expanded;
-       gint online;
-       gboolean send_offline;
-       gint default_chatb;
-       gint default_filetransb;
+       int expanded;
+       int online;
+       int send_offline;
+       int default_chatb;
+       int default_filetransb;
        struct _grouplist * group;
        struct _chat_window * chatwindow;
        struct _log_window* logwindow;
@@ -50,7 +50,7 @@
        void * pix; /* GtkWidget */
        void * status; /* GtkWidget */
        void * label; /* GtkWidget */
-       gint icon_handler;
+       int icon_handler;
 };
 
 

Index: llist.c
===================================================================
RCS file: /cvsroot/ayttm/ayttm/src/llist.c,v
retrieving revision 1.6
retrieving revision 1.7
diff -u -r1.6 -r1.7
--- llist.c     24 Jan 2003 20:41:31 -0000      1.6
+++ llist.c     27 Jan 2003 13:48:19 -0000      1.7
@@ -179,6 +179,15 @@
        return NULL;
 }
 
+LList *l_list_nth(LList * list, int n)
+{
+       int i=n;
+       for ( ; list && i; list = list->next, i--)
+               ;
+
+       return list;
+}
+
 LList *l_list_insert_sorted(LList * list, void *data, LListCompFunc comp)
 {
        LList *l, *n = malloc(sizeof(LList));

Index: llist.h
===================================================================
RCS file: /cvsroot/ayttm/ayttm/src/llist.h,v
retrieving revision 1.3
retrieving revision 1.4
diff -u -r1.3 -r1.4
--- llist.h     24 Jan 2003 20:41:31 -0000      1.3
+++ llist.h     27 Jan 2003 13:48:19 -0000      1.4
@@ -56,6 +56,8 @@
 LList *l_list_find(LList * list, const void *data);
 LList *l_list_find_custom(LList * list, const void *data, LListCompFunc comp);
 
+LList *l_list_nth(LList * list, int n);
+
 void l_list_foreach(LList * list, LListFunc fn, void *user_data);
 
 void l_list_free_1(LList * list);

Index: message_parse.h
===================================================================
RCS file: /cvsroot/ayttm/ayttm/src/message_parse.h,v
retrieving revision 1.4
retrieving revision 1.5
diff -u -r1.4 -r1.5
--- message_parse.h     16 Jan 2003 13:11:01 -0000      1.4
+++ message_parse.h     27 Jan 2003 13:48:19 -0000      1.5
@@ -41,10 +41,10 @@
 void eb_parse_incoming_message( eb_local_account * account,
                                  eb_account * remote,
                                  struct service * service,
-                                 gchar * message );
+                                 char * message );
 
 void eb_update_status( eb_account * remote,
-                       gchar * message );
+                       char * message );
 #ifdef __cplusplus
 } /* extern "C" */
 #endif

Index: plugin_api.c
===================================================================
RCS file: /cvsroot/ayttm/ayttm/src/plugin_api.c,v
retrieving revision 1.8
retrieving revision 1.9
diff -u -r1.8 -r1.9
--- plugin_api.c        26 Jan 2003 11:44:45 -0000      1.8
+++ plugin_api.c        27 Jan 2003 13:48:19 -0000      1.9
@@ -66,7 +66,7 @@
 {
        menu_item_data *mid=NULL;
        menu_data *md=NULL;
-       GList *list;
+       LList *list;
        
        eb_debug(DBG_CORE, ">Adding %s to menu %s\n", label, menu_name);
        md = GetPref(menu_name);
@@ -79,31 +79,31 @@
                eb_debug(DBG_CORE, "Incorrect ebmType passed, not adding menu 
item: %s\n", label);
                return(NULL);
        }
-       for(list = md->menu_items; list && list->data; list  = 
g_list_next(list) ){
+       for(list = md->menu_items; list && list->data; list = list->next ){
                menu_item_data *tmid = (menu_item_data *)list->data;
                if( tmid->callback == callback && !strcmp(tmid->label,label)) {
                        /* already in list */
                        return ((void *)tmid);
                }
        }
-       mid=g_new0(menu_item_data, 1);
+       mid=calloc(1, sizeof(menu_item_data));
        mid->user_data=data;
        mid->label=label;
        mid->callback=callback;
-       md->menu_items = g_list_append(md->menu_items, mid);
+       md->menu_items = l_list_append(md->menu_items, mid);
        if(md->redraw_menu) {
                eb_debug(DBG_CORE, "Calling redraw_menu for %s\n", menu_name);
                md->redraw_menu();
        }
        eb_debug(DBG_CORE, "<Successfully added menu item\n");
-       /* Return the menu_item_data pointer, so that g_list_remove can be used 
*/
+       /* Return the menu_item_data pointer, so that l_list_remove can be used 
*/
        return((void *)mid);
 }
 
 int eb_remove_menu_item(char *menu_name, void *tag)
 {
        menu_data *md=NULL;
-       menu_item_data *mid=(menu_item_data *)tag;
+       menu_item_data *mid=tag;
 
        if(mid) {
                eb_debug(DBG_CORE, ">Request to remove %s from menu %s\n", 
mid->label, menu_name);
@@ -117,7 +117,7 @@
                eb_debug(DBG_CORE, "<Requested menu %s does not exist, 
returning failure\n", menu_name);
                return(-1);
        }
-       md->menu_items=g_list_remove(md->menu_items, tag);
+       md->menu_items=l_list_remove(md->menu_items, tag);
        if(md->redraw_menu) {
                eb_debug(DBG_CORE, "Calling redraw_menu\n");
                md->redraw_menu();
@@ -128,18 +128,18 @@
 
 void eb_do_dialog(char *message, char *title, eb_callback_action action, void 
*data)
 {
-       callback_data *cd=g_new0(callback_data,1);
+       callback_data *cd=calloc(1, sizeof(callback_data));
        cd->action=action;
        cd->data=data;
        do_dialog(message, title, eb_gtk_dialog_callback, cd);
 }
 
-void eb_set_active_menu_status(GSList *status_menu, int status)
+void eb_set_active_menu_status(LList *status_menu, int status)
 {
        gtk_check_menu_item_set_active
                (GTK_CHECK_MENU_ITEM
                        (
-                        g_slist_nth(status_menu, status)->data
+                        l_list_nth(status_menu, status)->data
                         ), TRUE
                );
 }

Index: plugin_api.h
===================================================================
RCS file: /cvsroot/ayttm/ayttm/src/plugin_api.h,v
retrieving revision 1.3
retrieving revision 1.4
diff -u -r1.3 -r1.4
--- plugin_api.h        16 Jan 2003 13:11:01 -0000      1.3
+++ plugin_api.h        27 Jan 2003 13:48:19 -0000      1.4
@@ -97,7 +97,7 @@
 ebmCallbackData *ebmProfileData_new(eb_local_account * ela);
 ebmImportData *ebmImportData_new();
 ebmContactData *ebmContactData_new();
-void eb_set_active_menu_status(GSList *status_menu, int status);
+void eb_set_active_menu_status(LList *status_menu, int status);
 void eb_do_dialog(char *message, char *title, eb_callback_action action, void 
*data);
 
 /* eb_add_menu_item returns a tag, which can be used by eb_remove_menu_item 
@@ -139,9 +139,9 @@
 #include "debug.h"
 
 #if defined(__MINGW32__) && defined(__IN_PLUGIN__)
-__declspec(dllimport) gint do_plugin_debug;
+__declspec(dllimport) int do_plugin_debug;
 #else
-extern gint do_plugin_debug;
+extern int do_plugin_debug;
 #endif
 #define DBG_MOD do_plugin_debug
 

Index: prefs.c
===================================================================
RCS file: /cvsroot/ayttm/ayttm/src/prefs.c,v
retrieving revision 1.26
retrieving revision 1.27
diff -u -r1.26 -r1.27
--- prefs.c     24 Jan 2003 20:41:31 -0000      1.26
+++ prefs.c     27 Jan 2003 13:48:19 -0000      1.27
@@ -53,7 +53,7 @@
 #define rindex(a,b) strrchr(a,b)
 #endif
 
-static gint is_prefs_open = 0;
+static int is_prefs_open = 0;
 static GList *GLOBAL_PREFS=NULL;
 
 
@@ -224,35 +224,35 @@
 #ifdef HAVE_ISPELL
 static GtkWidget       *dictionary_entry = NULL;
 #endif
-static const gint      length_contact_window_default = 256;
-static const gint      width_contact_window_default = 150;
+static const int       length_contact_window_default = 256;
+static const int       width_contact_window_default = 150;
 
-static const gint      font_size_def = 4;
+static const int       font_size_def = 4;
 
-static gint    length_contact_window_old = 0;
+static int     length_contact_window_old = 0;
 
-static gint    do_login_on_startup = 0;
-static gint    do_login_on_startup_old = 0 ;
+static int     do_login_on_startup = 0;
+static int     do_login_on_startup_old = 0 ;
 
-gint           do_ayttm_debug = 0;
-static gint    do_ayttm_debug_old = 0;
+int            do_ayttm_debug = 0;
+static int     do_ayttm_debug_old = 0;
 
-gint           do_ayttm_debug_html = 0;
-static gint    do_ayttm_debug_html_old = 0;
+int            do_ayttm_debug_html = 0;
+static int     do_ayttm_debug_html_old = 0;
 
-gint           do_plugin_debug = 0;
-static gint    do_plugin_debug_old = 0;
+int            do_plugin_debug = 0;
+static int     do_plugin_debug_old = 0;
 
 #ifdef HAVE_ISPELL
-static gint    do_spell_checking = 0;
-static gint    do_spell_checking_old = 0;
+static int     do_spell_checking = 0;
+static int     do_spell_checking_old = 0;
 #endif
 
-static gint    do_noautoresize = 0;
-static gint    do_noautoresize_old = 0;
+static int     do_noautoresize = 0;
+static int     do_noautoresize_old = 0;
 
-static gint    use_alternate_browser = 0;
-static gint    use_alternate_browser_old = 0;
+static int     use_alternate_browser = 0;
+static int     use_alternate_browser_old = 0;
 
 #ifdef HAVE_ISPELL
 static void    set_use_spell(GtkWidget * w, int * data);
@@ -500,12 +500,12 @@
  * Logs Preferences Tab
  */
 
-static gint    do_logging = 1;
-static gint    do_logging_old = 1;
-static gint    do_strip_html = 0;
-static gint    do_strip_html_old = 0;
-static gint    do_restore_last_conv = 0;
-static gint    do_restore_last_conv_old = 0;
+static int     do_logging = 1;
+static int     do_logging_old = 1;
+static int     do_strip_html = 0;
+static int     do_strip_html_old = 0;
+static int     do_restore_last_conv = 0;
+static int     do_restore_last_conv_old = 0;
 
 static void build_logs_prefs(GtkWidget *prefs_note)
 {
@@ -541,12 +541,12 @@
  * Layout Preferences Tab
  */
 
-static gint do_tabbed_chat = 0;
-static gint do_tabbed_chat_old = 0;
+static int do_tabbed_chat = 0;
+static int do_tabbed_chat_old = 0;
 
 /* Tab Orientation:  0 => bottom, 1 => top, 2=> left, 3 => right */
-static gint do_tabbed_chat_orient = 0;
-static gint do_tabbed_chat_orient_old = 0;
+static int do_tabbed_chat_orient = 0;
+static int do_tabbed_chat_orient_old = 0;
 
 /*
   Callback function for setting element of Tabbed Chat Orientation radio
@@ -630,50 +630,50 @@
  * Chat Preferences Tab
  */
 
-static gint do_typing_notify = 1;
-static gint do_typing_notify_old = 1;
+static int do_typing_notify = 1;
+static int do_typing_notify_old = 1;
 
-static gint do_send_typing_notify = 1;
-static gint do_send_typing_notify_old = 1;
+static int do_send_typing_notify = 1;
+static int do_send_typing_notify_old = 1;
 
-static gint do_escape_close = 1;
-static gint do_escape_close_old = 1;
+static int do_escape_close = 1;
+static int do_escape_close_old = 1;
 
-static gint do_convo_timestamp = 1;
-static gint do_convo_timestamp_old = 1;
+static int do_convo_timestamp = 1;
+static int do_convo_timestamp_old = 1;
 
-static gint do_enter_send = 1;
-static gint do_enter_send_old = 1;
+static int do_enter_send = 1;
+static int do_enter_send_old = 1;
 
-static gint do_ignore_unknown = 0;
-static gint do_ignore_unknown_old = 0;
+static int do_ignore_unknown = 0;
+static int do_ignore_unknown_old = 0;
 
-static gint font_size_old = 4;
-static gint font_size = 4;
+static int font_size_old = 4;
+static int font_size = 4;
 
-static gint do_multi_line = 1;
-static gint do_multi_line_old = 1;
+static int do_multi_line = 1;
+static int do_multi_line_old = 1;
 
-static gint do_raise_window = 0;
-static gint do_raise_window_old = 0;
+static int do_raise_window = 0;
+static int do_raise_window_old = 0;
 
-static gint do_send_idle_time = 0;
-static gint do_send_idle_time_old = 0;
+static int do_send_idle_time = 0;
+static int do_send_idle_time_old = 0;
 
-static gint do_timestamp = 1;
-static gint do_timestamp_old = 1;
+static int do_timestamp = 1;
+static int do_timestamp_old = 1;
 
-static gint do_ignore_fore = 1;
-static gint do_ignore_fore_old = 1;
+static int do_ignore_fore = 1;
+static int do_ignore_fore_old = 1;
 
-static gint do_ignore_back = 1;
-static gint do_ignore_back_old = 1;
+static int do_ignore_back = 1;
+static int do_ignore_back_old = 1;
 
-static gint do_ignore_font = 1;
-static gint do_ignore_font_old = 1;
+static int do_ignore_font = 1;
+static int do_ignore_font_old = 1;
 
-static gint do_smiley = 1;
-static gint do_smiley_old = 1;
+static int do_smiley = 1;
+static int do_smiley_old = 1;
 
 GdkDeviceKey accel_prev_tab = { GDK_Left, GDK_CONTROL_MASK };
 GdkDeviceKey accel_next_tab = { GDK_Right, GDK_CONTROL_MASK };
@@ -685,12 +685,12 @@
 
 
 /* apparently all signal handlers are supposed to be boolean... */
-static gboolean newkey_callback (GtkWidget *keybutton, GdkEventKey *event, 
gint *userdata) {
+static gboolean newkey_callback (GtkWidget *keybutton, GdkEventKey *event, int 
*userdata) {
        GtkWidget *label = GTK_BIN(keybutton)->child;
        /* remove stupid things like.. numlock scrolllock and capslock
         * mod1 = alt, mod2 = numlock, mod3 = modeshift/altgr, mod4 = meta, 
mod5 = scrolllock */
        
-       gint state = event->state & (GDK_SHIFT_MASK | GDK_CONTROL_MASK | 
GDK_MOD1_MASK | GDK_MOD4_MASK);
+       int state = event->state & (GDK_SHIFT_MASK | GDK_CONTROL_MASK | 
GDK_MOD1_MASK | GDK_MOD4_MASK);
        if (state != 0) {
                        /* this unfortunately was the only way I could do this 
without using
                         * a key release event
@@ -746,7 +746,7 @@
        }
 }
 
-static void add_key_set(gchar *labelString,
+static void add_key_set(char *labelString,
                                        GdkDeviceKey *keydata,
                                        GtkWidget *vbox)
 {
@@ -911,9 +911,9 @@
 static GtkWidget * proxy_port_entry = NULL;
 static GtkWidget * proxy_user_entry = NULL;
 static GtkWidget * proxy_password_entry = NULL;
-static gint new_proxy_type;
-static gint do_proxy_auth;
-static gint do_proxy_auth_old;
+static int new_proxy_type;
+static int do_proxy_auth;
+static int do_proxy_auth_old;
 
 static void set_proxy_type(GtkWidget *w, int *data);
 
@@ -1166,7 +1166,7 @@
 
 #ifdef HAVE_ICONV_H
 #define ENCODE_LEN 64
-gint use_recoding = 0;
+int use_recoding = 0;
 
 static GtkWidget * modules_path_text = NULL;
 static GtkWidget * local_encoding_entry = NULL;
@@ -1408,7 +1408,7 @@
 typedef struct {
        GtkCList *clist;
        eb_PLUGIN_INFO *epi;
-       gint row;
+       int row;
 }Plugin_Callback_Data;
 
 static void reload_plugin_callback(GtkWidget * reload_button, gpointer 
userdata)
@@ -1509,14 +1509,14 @@
 }
 
 /* Sort the clist based upon the column passed */
-static void plugin_column_sort(GtkCList *clist, gint column, gpointer userdata)
+static void plugin_column_sort(GtkCList *clist, int column, gpointer userdata)
 {
        eb_debug(DBG_CORE, "Sorting on column: %i\n", column);
        gtk_clist_set_sort_column(GTK_CLIST(clist), column);
        gtk_clist_sort(GTK_CLIST(clist));
 }
 
-static void plugin_selected(GtkCList *clist, gint row, gint column, 
GdkEventButton *event, gpointer userdata)
+static void plugin_selected(GtkCList *clist, int row, int column, 
GdkEventButton *event, gpointer userdata)
 {
        char *plugin_path=NULL;
        eb_PLUGIN_INFO *epi=NULL;
@@ -1685,8 +1685,8 @@
                {
                        GtkLabel        *label = GTK_LABEL(gtk_label_new( NULL 
));
                        GString         *labelText = g_string_new( _("No 
preferences for ") );
-                       gint            newWidth = 0;
-                       gint            newHeight = 0;
+                       int             newWidth = 0;
+                       int             newHeight = 0;
                        
                        if ( epi->service != NULL )
                        {
@@ -1847,7 +1847,7 @@
        fprintf(fp,"end\n");
 }
 
-static gint compare_ptr_key(gconstpointer a, gconstpointer b) {
+static int compare_ptr_key(gconstpointer a, gconstpointer b) {
                if(!strcmp( ((ptr_list *)a)->key, (char *)b))
                        return(0);
                return(1);
@@ -1947,30 +1947,30 @@
  * Sound Preferences Tab
  */
 
-static gint    do_no_sound_when_away = 0;
-static gint    do_no_sound_when_away_old = 0;
+static int     do_no_sound_when_away = 0;
+static int     do_no_sound_when_away_old = 0;
 
-static gint    do_no_sound_for_ignore = 1;
-static gint    do_no_sound_for_ignore_old = 1;
+static int     do_no_sound_for_ignore = 1;
+static int     do_no_sound_for_ignore_old = 1;
 
-static gint    do_online_sound = 1;
-static gint    do_online_sound_old = 1;
+static int     do_online_sound = 1;
+static int     do_online_sound_old = 1;
 
-static gint    do_play_send = 1;
-static gint do_play_send_old = 1;
-
-static gint    do_play_first = 1;
-static gint    do_play_first_old = 1;
-
-static gint    do_play_receive = 1;
-static gint    do_play_receive_old = 1;
-
-static gchar BuddyArriveFilename_old[1024] = BuddyArriveDefault;
-static gchar BuddyAwayFilename_old[1024] = BuddyLeaveDefault;
-static gchar BuddyLeaveFilename_old[1024] = BuddyLeaveDefault;
-static gchar FirstMsgFilename_old[1024] = ReceiveDefault;
-static gchar ReceiveFilename_old[1024] = ReceiveDefault;
-static gchar SendFilename_old[1024] = SendDefault;
+static int     do_play_send = 1;
+static int do_play_send_old = 1;
+
+static int     do_play_first = 1;
+static int     do_play_first_old = 1;
+
+static int     do_play_receive = 1;
+static int     do_play_receive_old = 1;
+
+static char BuddyArriveFilename_old[1024] = BuddyArriveDefault;
+static char BuddyAwayFilename_old[1024] = BuddyLeaveDefault;
+static char BuddyLeaveFilename_old[1024] = BuddyLeaveDefault;
+static char FirstMsgFilename_old[1024] = ReceiveDefault;
+static char ReceiveFilename_old[1024] = ReceiveDefault;
+static char SendFilename_old[1024] = SendDefault;
 
 static gfloat volume_sound_old = 0;
 
@@ -1982,8 +1982,8 @@
 static GtkWidget *firstmsgsoundentry=NULL;
 static GtkWidget *volumesoundentry=NULL;
 
-static GtkWidget *add_sound_file_selection_box(gchar *, GtkWidget *, gchar *, 
int);
-static GtkWidget *add_sound_volume_selection_box(gchar *, GtkWidget *, 
GtkAdjustment *);
+static GtkWidget *add_sound_file_selection_box(char *, GtkWidget *, char *, 
int);
+static GtkWidget *add_sound_volume_selection_box(char *, GtkWidget *, 
GtkAdjustment *);
 /* Main Sound Preferences Funtion, hooks in the rest */
 
 static void build_sound_prefs(GtkWidget *prefs_note)
@@ -2121,9 +2121,9 @@
 static void testsoundfile (GtkWidget * sendf_button, int userdata);
 static void soundvolume_changed(GtkAdjustment * adjust, int userdata);
 
-static GtkWidget *add_sound_file_selection_box(gchar *labelString,
+static GtkWidget *add_sound_file_selection_box(char *labelString,
                                        GtkWidget *vbox,
-                                       gchar *initialFilename,
+                                       char *initialFilename,
                                        int userdata) 
 {
      GtkWidget *hbox;
@@ -2164,7 +2164,7 @@
      return widget;
 }
 
-static GtkWidget *add_sound_volume_selection_box(gchar *labelString,
+static GtkWidget *add_sound_volume_selection_box(char *labelString,
                                          GtkWidget *vbox,
                                          GtkAdjustment *adjust)
 {
@@ -2370,7 +2370,7 @@
  */
 void write_prefs()
 {
-     gchar buff[1024], file[1024];
+     char buff[1024], file[1024];
      FILE * fp;
      g_snprintf(buff, 1024, "%sprefs.tmp",config_dir);
      g_snprintf(file, 1024, "%sprefs",config_dir);
@@ -2397,11 +2397,11 @@
 // todo: re-organize to separate pref reading into modules
 void eb_read_prefs()
 {
-       gchar buff[1024];
+       char buff[1024];
        int pref_type=0;
        FILE * fp;
-       gchar *param=buff;
-       gchar *val=buff;
+       char *param=buff;
+       char *val=buff;
        /* Set some default values */
        iSetLocalPref("length_contact_window", length_contact_window_default);
        iSetLocalPref("width_contact_window", width_contact_window_default);

Index: sound.c
===================================================================
RCS file: /cvsroot/ayttm/ayttm/src/sound.c,v
retrieving revision 1.12
retrieving revision 1.13
diff -u -r1.12 -r1.13
--- sound.c     26 Jan 2003 11:44:45 -0000      1.12
+++ sound.c     27 Jan 2003 13:48:19 -0000      1.13
@@ -37,6 +37,7 @@
 #include <errno.h>
 #include <math.h>
 #include <unistd.h>
+#include <glib.h>
 
 #ifdef __MINGW32__
 #include <windows.h>

Index: status.c
===================================================================
RCS file: /cvsroot/ayttm/ayttm/src/status.c,v
retrieving revision 1.36
retrieving revision 1.37
diff -u -r1.36 -r1.37
--- status.c    27 Jan 2003 09:00:35 -0000      1.36
+++ status.c    27 Jan 2003 13:48:19 -0000      1.37
@@ -351,7 +351,7 @@
        menu_data *md=NULL;
        menu_item_data *mid=NULL;
        ebmContactData *ecd=NULL;
-       GList *list=NULL;
+       LList *list=NULL;
        int nbitems = 0;
        menu = gtk_menu_new();
        
@@ -1421,7 +1421,7 @@
          GtkWidget* hbox, *label;
          GtkStyle* style;
          GSList * group = NULL;
-         GSList * widgets = NULL;
+         LList * widgets = NULL;
          int x;
          gchar string[255];
          status_menu = gtk_menu_new();
@@ -1443,7 +1443,7 @@
                
                status_menu_item = gtk_radio_menu_item_new(group);
                group = 
gtk_radio_menu_item_group(GTK_RADIO_MENU_ITEM(status_menu_item));
-               widgets = g_slist_append(widgets, status_menu_item);
+               widgets = l_list_append(widgets, status_menu_item);
                hbox = gtk_hbox_new(FALSE, 3);
                label = gtk_label_new((gchar*)temp_list->data);
                
@@ -1467,10 +1467,10 @@
        ela->status_button = gtk_menu_item_new_with_label(string);
   
        /* First deactivate zeroth status radio item */
-       GTK_CHECK_MENU_ITEM(g_slist_nth(widgets, 0)->data)->active = 0 ;
+       GTK_CHECK_MENU_ITEM(l_list_nth(widgets, 0)->data)->active = 0 ;
        /* Now, activate the desired status radio item */
        GTK_CHECK_MENU_ITEM(
-               g_slist_nth(widgets, 
eb_services[ela->service_id].sc->get_current_state(ela))->data)->active = 1 ;
+               l_list_nth(widgets, 
eb_services[ela->service_id].sc->get_current_state(ela))->data)->active = 1 ;
   
        gtk_menu_item_set_submenu(GTK_MENU_ITEM(ela->status_button), 
status_menu);
        l_list_free(status_label);
@@ -1504,7 +1504,7 @@
 {
        GtkWidget *profile_submenuitem = v_profile_submenuitem;
        GtkWidget *label;
-       GList *list=NULL;
+       LList *list=NULL;
        GtkWidget * profile_menu = gtk_menu_new();
        menu_data *md=NULL;
        menu_item_data *mid=NULL;
@@ -1537,7 +1537,7 @@
 {
        GtkWidget * import_submenuitem = v_import_submenuitem;
        GtkWidget *label;
-       GList *list=NULL;
+       LList *list=NULL;
        GtkWidget * import_menu = gtk_menu_new();
        menu_data *md=NULL;
        menu_item_data *mid=NULL;

Index: util.c
===================================================================
RCS file: /cvsroot/ayttm/ayttm/src/util.c,v
retrieving revision 1.27
retrieving revision 1.28
diff -u -r1.27 -r1.28
--- util.c      24 Jan 2003 20:41:31 -0000      1.27
+++ util.c      27 Jan 2003 13:48:19 -0000      1.28
@@ -1330,9 +1330,9 @@
 #endif
 }
 
-void eb_generic_menu_function(void *add_button, gpointer userdata)
+void eb_generic_menu_function(void *add_button, void * userdata)
 {
-       menu_item_data *mid=(menu_item_data *)userdata;
+       menu_item_data *mid=userdata;
        ebmCallbackData *ecd=NULL;
 
        assert(userdata);

Index: util.h
===================================================================
RCS file: /cvsroot/ayttm/ayttm/src/util.h,v
retrieving revision 1.15
retrieving revision 1.16
diff -u -r1.15 -r1.16
--- util.h      24 Jan 2003 13:34:41 -0000      1.15
+++ util.h      27 Jan 2003 13:48:19 -0000      1.16
@@ -36,6 +36,7 @@
 # include <process.h>
 #endif
 
+#include <glib.h>      /* for llist_to_glist and glist_to_llist */
 #include "contact.h"
 
 
@@ -87,7 +88,7 @@
 
 eb_local_account * find_suitable_local_account( eb_local_account * first,
                                                int second );
-eb_local_account * find_local_account_for_remote( eb_account *remote, gboolean 
online );
+eb_local_account * find_local_account_for_remote( eb_account *remote, int 
online );
 eb_account * can_offline_message( struct contact * con );
 
 eb_account * find_suitable_remote_account( eb_account * first,
@@ -125,7 +126,7 @@
 
 pid_t create_lock_file(char* fname);
 void delete_lock_file(char* fname);
-void eb_generic_menu_function(void *add_button, gpointer userdata);
+void eb_generic_menu_function(void *add_button, void * userdata);
 LList * get_groups();
 void contact_mgmt_queue_add(eb_account *ea, int action, char *group);
 int contact_mgmt_flush(eb_local_account *ela);





reply via email to

[Prev in Thread] Current Thread [Next in Thread]
Index: plugin.h
===================================================================
RCS file: /cvsroot/ayttm/ayttm/src/plugin.h,v
retrieving revision 1.4
retrieving revision 1.5
diff -u -r1.4 -r1.5
--- plugin.h    21 Jan 2003 01:11:01 -0000      1.4
+++ plugin.h    27 Jan 2003 13:48:19 -0000      1.5
@@ -63,7 +63,7 @@
 
 typedef void (*menu_func)();
 typedef struct {
-       GList *menu_items;      /* A GList of menu_item_data elements */
+       LList *menu_items;      /* A LList of menu_item_data elements */
        menu_func redraw_menu;  /* The function to call when the menu is 
changed */
        ebmType type;           /* What kind of data structure do we send back? 
*/
 } menu_data;
